
local accel, friction = 1800, 0.03
local maxLength = 30

local function update(dragon, ax, ay, dt)
	local x, y, r = dragon.x, dragon.y, dragon.r
	local vx, vy = dragon.vx, dragon.vy
	vx = vx  +  ax * accel * dt  -  friction * vx
	vy = vy  +  ay * accel * dt  -  friction * vy
	if math.abs(vx) < 0.1 then vx = 0 end
	if math.abs(vy) < 0.1 then vy = 0 end
	x = x + vx * dt
	y = y + vy * dt
	if x < r then x, vx = r, -vx
	elseif x > w - r then x, vx = w - r, -vx end
	if y < r then y, vy = r, -vy
	elseif y > h - r then y, vy = h - r, -vy end
	dragon.vx, dragon.vy = vx, vy
	dragon.x, dragon.y = x, y
	table.insert(dragon, {x, y})
	if #dragon > maxLength then table.remove(dragon, 1) end
end

local function draw(dragon)
	for i=1,#dragon do
		local x, y = unpack(dragon[i])
		local r = dragon.r - (#dragon - i)*dragon.dr
		love.graphics.circle('fill', x, y, r)
	end
end

local function onresize(dragon, oldw, oldh)
	local dx = dragon.x * w / oldw  -  dragon.x
	local dy = dragon.y * h / oldh  -  dragon.y
	dragon.x = dragon.x + dx
	dragon.y = dragon.y + dy
	for i=1,#dragon do
		dragon[i][1] = dragon[i][1] + dx
		dragon[i][2] = dragon[i][2] + dy
	end
end

local methods = { update = update, draw = draw, onresize = onresize }
local class = { __index = methods }

local function new(x, y, r)
	local d = {
		{ x, y },
		x = x, y = y,
		vx = 0, vy = 0,
		r = r, dr = r / maxLength
	}
	return setmetatable(d, class)
end

return { new = new, methods = methods, class = class }
