local function update(fly, dt)
	fly.vx = fly.speed * math.cos(fly.angle)
	fly.vy = fly.speed * math.sin(fly.angle)
	fly.x = fly.x + fly.vx * dt
	fly.y = fly.y + fly.vy * dt
	fly.angle = fly.angle + fly.turn * dt
end

local function draw(fly)
	ux, uy = math.cos(fly.angle), math.sin(fly.angle)
	local separation = 3
	local x0, y0 = fly.x - separation*ux, fly.y - separation*uy
	local x1, y1 = fly.x + separation*ux, fly.y + separation*uy
	love.graphics.circle('fill', x0, y0, fly.r)
	love.graphics.circle('fill', x1, y1, fly.r)
end

local function onresize(fly, oldw, oldh)
	fly.x = fly.x * w / oldw
	fly.y = fly.y * h / oldh
end

local methods = { update = update, draw = draw, onresize = onresize }
local class = { __index = methods }

local function new()
	local f = {
		x = math.random(math.floor(w/6), math.ceil(5*w/6)),
		y = math.random(math.floor(h/6), math.ceil(5*h/6)),
		r = 4,
		speed = 200 + math.random(300),
		angle = 2*math.pi*math.random(),
		turn = (1 + 1*math.random())*math.pi * (math.random() < 0.5 and -1 or 1)
	}
	f.vx = f.speed * math.cos(f.angle)
	f.vy = f.speed * math.sin(f.angle)
	return setmetatable(f, class)
end

return { new = new, methods = methods, class = class }
